@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for getdefs
- * Generated Fri Jun 25 14:11:19 PDT 2010
+ * Generated Tue Sep  7 17:54:40 PDT 2010
  */
 #ifndef GETDEFS_PROTO_H_GUARD
 #define GETDEFS_PROTO_H_GUARD 1
@@ -37,7 +37,7 @@ validateOptions( void );
  *  Extracted from getdefs.c
  */
 LOCAL char*
-loadFile( tCC* pzFname );
+loadFile(char const * pzFname);
 
 #ifdef REDEF_LOCAL
 #  undef LOCAL
